-- FS25_MonumentRestoration/scripts/BankAccountHUD.lua

BankAccountHUD = {}
local BankAccountHUD_mt = Class(BankAccountHUD, MessageDialog)

function BankAccountHUD.register()
    print("[BankAccountHUD] Вызов функции register")
    if not g_gui then
        print("[BankAccountHUD] Ошибка: g_gui не инициализирован")
        return false
    end
    local guiPath = PlaceableBankAccount.modDirectory .. "gui/BankAccountHUD.xml"
    print("[BankAccountHUD] Попытка загрузки GUI из: " .. tostring(guiPath))
    if not fileExists(guiPath) then
        print("[BankAccountHUD] Ошибка: Файл GUI не найден по пути: " .. tostring(guiPath))
        return false
    end
    local guiObject = BankAccountHUD.new()
    local success = g_gui:loadGui(guiPath, "BankAccountHUD", guiObject)
    print("[BankAccountHUD] Результат загрузки GUI: " .. tostring(success))
    if not success then
        print("[BankAccountHUD] Ошибка: Не удалось загрузить GUI из: " .. tostring(guiPath))
        guiObject:delete()
        return false
    end
    BankAccountHUD.INSTANCE = guiObject
    print("[BankAccountHUD] Зарегистрирован диалог BankAccountHUD, INSTANCE: " .. tostring(BankAccountHUD.INSTANCE))
    return true
end

function BankAccountHUD.new(target, custom_mt)
    local self = MessageDialog.new(target, custom_mt or BankAccountHUD_mt)
    self.bank = nil
    print("[BankAccountHUD] Создан новый экземпляр BankAccountHUD")
    return self
end

function BankAccountHUD:delete()
    print("[BankAccountHUD] Удаление экземпляра BankAccountHUD")
    self.bank = nil
    MessageDialog.delete(self)
end

function BankAccountHUD:onGuiSetupFinished()
    print("[BankAccountHUD] Вызван onGuiSetupFinished")
    MessageDialog.onGuiSetupFinished(self)
end

function BankAccountHUD:onCreate()
    print("[BankAccountHUD] Вызван onCreate")
    MessageDialog.onCreate(self)
    local elementIds = {}
    if self.elementsById then
        for key, _ in pairs(self.elementsById) do
            table.insert(elementIds, key)
        end
    end
    print("[BankAccountHUD] Доступные ID элементов: " .. table.concat(elementIds, ", "))
    print("[BankAccountHUD] titleElement: " .. tostring(self.titleElement))
    print("[BankAccountHUD] balanceElement: " .. tostring(self.balanceElement))
    print("[BankAccountHUD] depositButton: " .. tostring(self.depositButton))
    print("[BankAccountHUD] withdrawButton: " .. tostring(self.withdrawButton))
    print("[BankAccountHUD] closeButton: " .. tostring(self.closeButton))
end

function BankAccountHUD:onOpen()
    print("[BankAccountHUD] Вызван onOpen")
    MessageDialog.onOpen(self)
    self:updateData()
    self:setSoundSuppressed(true)
    FocusManager:setFocus(self.closeButton)
    self:setSoundSuppressed(false)
    print("[BankAccountHUD] Начальный фокус установлен на closeButton")
end

function BankAccountHUD:onClose()
    print("[BankAccountHUD] Вызван onClose")
    self.bank = nil
    MessageDialog.onClose(self)
end

function BankAccountHUD:updateData()
    print("[BankAccountHUD] Вызван updateData")
    if not self.bank then
        print("[BankAccountHUD] Ошибка: Банк не назначен")
        return
    end
    
    local titleElement = self.titleElement
    local balanceElement = self.balanceElement
    local depositButton = self.depositButton
    local withdrawButton = self.withdrawButton
    
    if titleElement then
        titleElement:setText(g_i18n:getText("ui_bankAccount_title"))
    end
    if balanceElement then
        balanceElement:setText(string.format(g_i18n:getText("ui_bankAccount_balance"), math.floor(self.bank:getBalance())))
    end
    if depositButton then
        depositButton:setDisabled(false)
        depositButton:setText(g_i18n:getText("ui_bankAccount_deposit"))
    end
    if withdrawButton then
        local balance = self.bank:getBalance()
        if balance > 0 then
            withdrawButton:setDisabled(false)
            withdrawButton:setText(g_i18n:getText("ui_bankAccount_withdraw"))
        else
            withdrawButton:setDisabled(true)
            withdrawButton:setText(g_i18n:getText("ui_bankAccount_withdraw"))
        end
    end
end

function BankAccountHUD:onClickDeposit()
    print("[BankAccountHUD] Вызван onClickDeposit")
    if self.bank then
        self.bank:depositMoney()
        self:updateData()
    end
end

function BankAccountHUD:onClickWithdraw()
    print("[BankAccountHUD] Вызван onClickWithdraw")
    if self.bank then
        self.bank:withdrawMoney()
        self:updateData()
    end
end

function BankAccountHUD:onClickClose()
    print("[BankAccountHUD] Вызван onClickClose")
    self:close()
end